<?php

namespace App\Http\Controllers;
use Carbon\Carbon;
use App\Models\Item;
use App\Models\Image;
use App\Models\Order;
use App\Models\Invoice;
use App\Models\Product;
use App\Models\Category;
use App\Models\Purchase;
use App\Models\Supplier;
use App\Models\Inventory;
use App\Models\Order_Item;
use Illuminate\Support\Arr;
use Illuminate\Http\Request;
use App\Imports\ProductsImport;
use App\Imports\CategoriesImport;
use Illuminate\Support\Facades\DB;
use Maatwebsite\Excel\Facades\Excel;
use Illuminate\Support\Facades\Route;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    /**
     * Show the application dashboard.
     *
     * @return \Illuminate\Contracts\Support\Renderable
     */
    public function index()
    {
        $cats = Category::all();
        $categories = Category::all()->count();
        $all_categories = Category::select(array('name_en' , 'name_ar'))->get();
        $top_5_selling_products = Product::withCount(['orders'])->orderBy('orders_count', 'desc')->take(5)->get();

        $total_top_5 = 0;
        foreach($top_5_selling_products as $top_5){
            $total_top_5 +=$top_5->orders()->sum('total_amount');
        }

        $products = Product::all();
        $suppliers = Supplier::all()->count();
        $purchases = Purchase::all()->count();
        $orders = Order::all()->count();
        $invoice = Invoice::all()->count();
        $orders = Order::all()->count();

        $total_amount = round(Order_Item::sum('total_amount'),2);
        $taxable_amount = round(Order_Item::sum('taxable_amount'),2);
        $tax_amount = round(Order_Item::sum('tax_amount'),2);

        $dataPoints_product = [];
        $product_chart_label=[];
        $product_chart_data =[];
        foreach ($products as $prod) {
            $product_chart_label[]  =$prod['name_en'];
            $product_chart_data[]   = intval($prod->orders->count());
            $dataPoints_product[] = array(
                $prod['name_en'] ,intval($prod->orders->count())
            );
        }
        $product_chart = json_encode($dataPoints_product);

        $top_categories = [['',0,''],['',0,''],['',0,''],['',0,''],['',0,'']];

        $dataPoints = [];
        $cat_product = Category::withCount(['products'])->orderBy('products_count', 'desc')->get();

        foreach ($cats as $cat) {
            $cat_pro_ord =0;
            foreach ($cat->products as $pro) {
                $cat_pro_ord += $pro->orders->count();
            }
            $cat['cat_product_order_count'] = $cat_pro_ord;
            $dataPoints[] = array(
                $cat['name_en'] ,intval($cat_pro_ord)
            );
            $top_categories[] = array(
                $cat['name_en'] ,intval($cat_pro_ord), $cat['name_ar']
            );
            if($cat_pro_ord>$top_categories[0][1]) $top_categories[0]=[ $cat['name_en'] ,intval($cat_pro_ord), $cat['name_ar']];
            else if ($cat_pro_ord>$top_categories[1][1]) $top_categories[1]=[ $cat['name_en'] ,intval($cat_pro_ord), $cat['name_ar']];
            else if ($cat_pro_ord>$top_categories[2][1]) $top_categories[2]=[ $cat['name_en'] ,intval($cat_pro_ord), $cat['name_ar']];
            else if ($cat_pro_ord>$top_categories[3][1]) $top_categories[3]=[ $cat['name_en'] ,intval($cat_pro_ord), $cat['name_ar']];
            else if ($cat_pro_ord>$top_categories[4][1]) $top_categories[4]=[ $cat['name_en'] ,intval($cat_pro_ord), $cat['name_ar']];


        }

        $top_categories = array_slice($top_categories, 0, 5, true);
       // $cat_chart = json_encode($dataPoints);
        $top_products = Product::withCount('orders')->orderBy('orders_count', 'desc')->take(5)->get();

        $dataPoints = [];
        foreach ($cats as $cat) {
            $cat_array = [$cat['name_en'],0,0,0,0,0,0,0,0,0,0];
            for ($month = 1; $month <= 12; $month++) {
                // Create a Carbon object from the current year and the current month (equals 2019-01-01 00:00:00)
                $date = Carbon::create(date('Y'), $month);
                // Make a copy of the start date and move to the end of the month (e.g. 2019-01-31 23:59:59)
                $date_end = $date->copy()->endOfMonth();
                $cat_pro_ord =0;
                foreach ($cat->products as $pro) {
                    $cat_pro_ord += $pro->orders
                    ->where('created_at', '>=', $date)
                    ->where('created_at', '<=', $date_end)
                    ->count();
                }
                $cat_array[$month] = $cat_pro_ord;
              //  $dataPoints[] = array(
               //     $cat['name_en'] ,intval($cat_pro_ord)
               // );
            }
            array_push($dataPoints,$cat_array);
        }
      // $dataPoints = [["Coffee",0,0,0,0,0,24,0,0,0,0,0,0],["Tea",0,0,0,0,0,2,0,0,0,0,0,0],["Espresso",0,1,2,0,0,0,0,0,0,0,0,0],["Juices",0,0,0,0,0,0,0,0,0,0,0,0]];
        $cat_chart = json_encode($dataPoints);

        $items = Item::all();
        $dataPoints2 = [];
        if(count($items)>0){
            foreach ($items as $item) {
                $inv = Inventory::where('item_id',$item->id)->first();
                if(isset($inv)){
                    $dataPoints2[]=array(
                        $item['name_en'],intval($inv['quantity']));
                }
                // $dataPoints2[] = array(
                //     isset($ing)?intval($ing['name_en']):'' ,isset($ing)?intval($ing['quantity']):0
                // );
            }
        }
        $inventory_chart = json_encode($dataPoints2);

        $opened_orders = Order::where('order_status',1)->count();
        $closed_orders = Order::where('order_status',3)->count();
        $cancelled_orders = Order::where('order_status',2)->count();
     //   return $top_5_selling_products;
        return view('layouts/master')->with([
        // return view('layouts/master2')->with([
            'product_chart_label'   => $product_chart_label,
            'product_chart_data'    => $product_chart_data,
            'top_categories'        => $top_categories,
            'top_products'          => $top_products ,
            'product_chart'         => $product_chart,
            'cat_chart'             => $cat_chart,
            'inventory_chart'       => $inventory_chart,
            'invoice'               => $invoice,
            'categories'            => $categories,
            'products'              => $products,
            'suppliers'             => $suppliers,
            'purchases'             => $purchases,
            'orders'                =>$orders,
            'invoice'               => $invoice,
            'total_amount'          => $total_amount,
            'taxable_amount'        => $taxable_amount,
            'tax_amount'            => $tax_amount,
            'opened_orders'         => $opened_orders,
            'closed_orders'         => $closed_orders,
            'cancelled_orders'      => $cancelled_orders,
            'top_5_selling_products'=> $top_5_selling_products,
            'total_top_5'           => $total_top_5
        ]);
    }

    // functions to upload files
    public function uploadFiles_page(){
        return view('dashboard.general_settings.images');
    }


//     public function uploadFile(Request $request)
//     {
//         dd($request->all());
//         $url = url()->previous();
//         $last = basename($url);
//         $this->getDownload($last);
// //        if(!in_array( $last, ['categories', 'products']))
// //        {
// //            throw new \Exception('Invalid model');
// //        }
//        // dd($last);
//         return view("dashboard.$last.upload",compact('last'));
//        // $this->uploadContent($request, $last);
//     }

    // public function getDownload($last)
    // {
    //     if($last == 'categories')
    //     {
    //         $file = public_path() . "/files/Category.xlsx";

    //         return response()->download($file);
    //     }
    //     else if ($last == 'products')
    //     {
    //         $file = public_path() . "/files/Product.xlsx";
    //         return response()->download($file);
    //     }
    // }
    public function uploadContent(Request $request)
    {

        // $f = ucfirst($last.'Import');
        // dd($request->file('uploads')['category']);

        $msg = '';

        if (isset($request->uploads['category']) && !is_null($request->uploads['category']))
        {
            Excel::import(new CategoriesImport, $request->file('uploads')['category']);
            $msg = 'Category Imported Successfully';
        }
        if (isset($request->uploads['product']) && !is_null($request->uploads['product']))
        {
            Excel::import(new ProductsImport, $request->uploads['product']);
            $msg .=' & Product Imported Successfully';
        }

        if ($request->has('filesuploaded')) {
            foreach ($request->file('filesuploaded') as $imagefile) {
                // dd($imagefile);
                $imageName = $imagefile->getClientOriginalName();
                $name = pathinfo($imageName, PATHINFO_FILENAME);
                $imagefile->move('images/', $imageName);
                $path = 'images/' . $name ;
                $image = new Image();
                $image->name = $name;
                $image->url = $path;
                $image->save();
            }
            $result  = $this->mapping($imagefile->getClientOriginalExtension());
            // if($result){
                $msg  = 'Images Uploaded Successfully';
                // Flash::success($msg);
            // }else{
                // $msg  =  "Can't upload image be sure image name equal product code";
                // Flash::error($msg);
            // }
        }
        return redirect()->route('uploadFiles_page')->with('success',$msg);
    }

    public function mapping($ex)
    {
        $products = Product::all();

        $images   = Image::all();
        foreach ($products as $product) {
            foreach ($images as $image) {
                if ($image->name == $product->code) {
                    $product->image = $image->name .'.'.$ex;
                    $product->save();
                }
            }
        }
    }
}
