<?php

namespace App\Http\Controllers\dashboard;

use App\Http\Controllers\Controller;
use App\Models\Inventory;
use App\Models\Item;
use App\Models\Purchase;
use App\Models\Supplier;
use App\Models\Items;
use Illuminate\Http\Request;
use Flash;
use Illuminate\Support\Facades\Validator;


class PurchaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $purchases = Purchase::with('Suppliers')->orderBy('created_at','desc')->get();

        return view('dashboard.purchases.index',compact('purchases'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $items =Item::select('name_en','name_ar','id')->distinct()->get();
        $suppliers = Supplier::all();
        return view('dashboard.purchases.add',compact('suppliers','items'));

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {

        // dd($request->all());
        $rule  =  array(
            'invoice' => 'required | string',
            'invoice_date' => 'required',
            'invoice_due_date' => 'string | required',
            'total_amount' =>'required|numeric',
            'supplier' => 'required ',
            'payment_method' => 'required',
            'VAT_number' => 'required | string ',
            'paid_amount' => 'required|numeric',
        ) ;
        $customMessages = [
            'required' => 'The :attribute field is required.',
            'VAT_number.required' => 'Tha vat number field is required.',
            'VAT_number.string' => 'Tha vat number field  must be a string.',
        ];

        if($request->detail_id_1 == null && $request->detail_id == null ){
            $rule3  =  array(
                'item_en' =>  "required|array|min:1|nullable",
                'item_en.*' =>  "required",
                'expiry_date' =>  "required|array|min:1|nullable",
                'expiry_date.*' =>  "required",
            ) ;

            $customMessages3 = [
                'item_en.*.required' => 'One item is required at least.',
                'expiry_date.*.required' => 'Expiry date for item is required.',
            ];
            $validator3 = Validator::make($request->all(),$rule3, $customMessages3);
            if($validator3->fails()) {
                Flash::error($validator3->errors());
                return back()->withErrors($validator3->errors());
            }
        }

        if($request->detail_id != null){
            $rule2  =  array(
                'item_en' =>  "required|array|min:1|nullable",
                'item_en.*' =>  "required",
                'expiry_date' =>  "required|array|min:1|nullable",
                'expiry_date.*' =>  "required",
            ) ;
            $customMessages2 = [
                'item_en.*.required' => 'Item english name is required and must be string.',
               // 'item_name_ar.*.required' => 'Item arabic name is required and must be string.',
                'expiry_date.*.required' => 'Expiry date for item is required.',
            ];
            $validator2 = Validator::make($request->all(),$rule2, $customMessages2);
            if($validator2->fails()) {
                Flash::error($validator2->errors());
                return back()->withErrors($validator2->errors());
            }
        }

        if($request->detail_id_1 != null){
            $rule4  =  array(
                'item_name_en' =>  "required|array|min:1|nullable",
                'item_name_en.*' =>  "required",
                'item_name_ar' =>  "required|array|nullable|min:1",
                'item_name_ar.*' =>  "required",
                'expiry_date_item' =>  "required|array|min:1|nullable",
                'expiry_date_item.*' =>  "required",
            ) ;
            $customMessages4 = [
                'item_name_en.*.required' => 'Item english name is required and must be string.',
                'item_name_ar.*.required' => 'Item arabic name is required and must be string.',
                'expiry_date_item.*.required' => 'Expiry date for item is required.',
            ];
            $validator4 = Validator::make($request->all(),$rule4, $customMessages4);
            if($validator4->fails()) {
                Flash::error($validator4->errors());
                return back()->withErrors($validator4->errors());
            }
        }

        $validator = Validator::make($request->all(),$rule, $customMessages);
        if($validator->fails()) {
            Flash::error($validator->errors());
            return back()->withErrors($validator->errors());
        } else {
            $purchase = new Purchase();
            $purchase->	invoice_number      = $request->input('invoice');
            $purchase->invoice_date         = $request->input('invoice_date');
            $purchase->invoice_due_date     = $request->input('invoice_due_date');
            $purchase->total_amount         = $request->input('total_amount');
            $purchase->payment_method       = $request->input('payment_method');
            $purchase->VAT_number           = $request->input('VAT_number');
            $purchase->paid_amount          = $request->input('paid_amount');
            $image = $request->file('image');
            if (isset($image)) {
                $imageName = time() . '.' . $image->getClientOriginalExtension();
                $image->move('images', $imageName);
                $purchase->image = $imageName;
            }else{
                $purchase->image = '';
            }
            $name  = $request->input('sname');

            // if add new supplier
            if (isset($name)) {
                $supplier  = new Supplier();
                $supplier->name         = $request->sname;
                $supplier->vat_number   = $request->VAT_number;
                $supplier->save();
                // $supplier  = Supplier::create([
                //     'name' => $request->sname,
                //     'vat_number' => $request->input('VAT_number'),
                //     'email' => '',
                //     'registeration_number' => '',
                //     // 'payment_method' => '',
                //     'address' => '',
                //     'city' => '',
                //     'country' => '',
                //     'contact_person' => '',
                //     'contact_person_phone' => '',
                //     'contact_person_email' => '',
                // ]);
                $purchase->supplier_id  = $supplier->id;
            }
            else{
                $purchase->supplier_id = $request->input('supplier');
            }
            $purchase->save();

            if ($request->detail_id != null ) {
                $items = $request->detail_id;
                    foreach ($items as $item) {
                        $item_p = Item::where('id','=',$request->item_en[$item])->first();
                        if($item_p)
                        {
                            $purchase->items()->attach($item_p->id,[
                                'mesurment'=>$request->measurement[$item],
                                'quantity' => $request->quantity[$item],
                                'expire_date' => $request->expiry_date[$item],
                            ]);
                        }
                        $inventory =null;
                        $inventory =Inventory::where('item_id','=',$item_p->id)->first();
                        $quantity = ($request->measurement[$item]) *( $request->quantity[$item]);
                        if($inventory){
                            $inventoryQuantity = $inventory->quantity;
                            $inventory->quantity =  $inventoryQuantity + $quantity;
                            $inventory->save();
                        }else{
                            $inventory = new Inventory(['item_id'=>$item_p->id ,'quantity' =>$quantity]);
                            $inventory->save();
                        }
                    }
            }
            if ($request->detail_id_1 ) {
                $items_1 = $request->detail_id_1;
                foreach ($items_1 as $item_1) {
                    $item = Item::create([
                        'name_en' => $request->item_name_en[$item_1],
                        'name_ar' => $request->item_name_ar[$item_1],
                        'unit' => $request->item_unit[$item_1]
                    ]);
                    $purchase->items()->attach($item->id,[
                        'mesurment'=>$request->measurement_item[$item_1],
                        'quantity' => $request->quantity_item[$item_1],
                        'expire_date' => $request->expiry_date_item[$item_1],
                    ]);

                    //SAVE TO INVENTORY
                    $inventory =null;
                    $inventory =Inventory::where('item_id','=',$item->id)->first();
                    $quantity = $request->measurement_item[$item_1] * $request->quantity_item[$item_1];
                    if($inventory){
                        $inventoryQuantity = $inventory->quantity;
                        $inventory->quantity =  $inventoryQuantity + $quantity;
                        $inventory->save();
                    }else{
                        $inventory = new Inventory(['item_id'=>$item->id ,'quantity' =>$quantity]);
                        $inventory->save();
                    }
                }
            }
            Flash::success('Purchase Created');
            return redirect()->route('purchases.index');
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function show($purchase)
    {
        $purchase = Purchase::with(['Suppliers','items'])->where('id',$purchase)->first();
        if (empty($purchase)) {
            Flash::error('Purchase Not Found');
            return redirect(route('purchases.index'));
        }
        return view('dashboard.purchases.show',compact('purchase'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function edit($purchase)
    {
        //
        $purchase = Purchase::with(['suppliers','items'])->where('id',$purchase)->first();
      //  $suppliers = Supplier::all();

    //    $items =Item::select('name_en','name_ar')->distinct()->get();

        $items =Item::select('name_en','name_ar','id')->distinct()->get();
        $suppliers = Supplier::all();

        return view('dashboard.purchases.edit',compact('purchase','suppliers','items'));

    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $purchase)
    {
        // dd($request->all());
        $rule  =  array(
            'invoice' => 'required | string',
            'invoice_date' => 'required',
            'invoice_due_date' => 'string | required',
            'total_amount' => 'required|numeric',
            'supplier' => 'required ',
            'payment_method' => 'required',
            'VAT_number' => 'required | string ',
            'paid_amount' => 'required|numeric',
        ) ;

        $customMessages = [
            'required' => 'The :attribute field is required.',
            'VAT_number.required' => 'Tha vat number field is required.',
            'VAT_number.string' => 'Tha vat number field  must be a string.',
        ];

        $validator = Validator::make($request->all(),$rule, $customMessages);
        if($validator->fails()) {
            Flash::error($validator->errors());
            return back()->withErrors($validator->errors());
        } else {
        $purchase = Purchase::find($purchase);
        $purchase->	invoice_number      = $request->input('invoice');
        $purchase->invoice_date         = $request->input('invoice_date');
        $purchase->invoice_due_date     = $request->input('invoice_due_date');
        $purchase->total_amount         = $request->input('total_amount');
        $purchase->payment_method       = $request->input('payment_method');
        $purchase->VAT_number           = $request->input('VAT_number');
        $purchase->paid_amount          = $request->input('paid_amount');
        $image = $request->file('image');
        if (isset($image)) {
            $imageName = time() . '.' . $image->getClientOriginalExtension();
            $image->move('images', $imageName);
            $purchase->image = $imageName;
        }else{
            $purchase->image = '';
        }
        $name  = $request->input('sname');

       // if add new supplier
       if (isset($name)) {
            $supplier  = new Supplier();
            $supplier->name         = $request->sname;
            $supplier->vat_number   = $request->VAT_number;
            $supplier->save();
            $purchase->supplier_id  = $supplier->id;
        }
        else{
            $supplier   = Supplier::where('id','=',$request->input('supplier'))->first();
            if($supplier->vat_number != $request->VAT_number){
                $supplier->vat_number =$request->VAT_number;
                $supplier->save();
            }
            $purchase->supplier_id = $request->input('supplier');
        }
        $purchase->save();

        if ($request->detail_id != null ) {
            $items = $request->detail_id;

                foreach ($items as $item) {
                    $item_p = Item::where('id',$request->item_en[$item])->first();

                    if($item_p)
                    {
                        $purchase->items()->attach($item_p->id,[
                            'mesurment'=>$request->measurement[$item],
                            'quantity' => $request->quantity[$item],
                            'expire_date' => $request->expiry_date[$item],
                        ]);
                    }
                }
        }
        if ($request->detail_id_1 ) {
            $items_1 = $request->detail_id_1;
            foreach ($items_1 as $item_1) {
                $item = Item::create([
                    'name_en' => $request->item_name_en[$item_1],
                    'name_ar' => $request->item_name_ar[$item_1],
                    'unit' => $request->item_unit[$item_1]
                ]);
                $purchase->items()->attach($item->id,[
                    'mesurment'=>$request->measurement_item[$item_1],
                    'quantity' => $request->quantity_item[$item_1],
                    'expire_date' => $request->expiry_date_item[$item_1],
                ]);

                //SAVE TO INVENTORY
                $inventory =null;
                $inventory =Inventory::where('item_id','=',$item->id)->first();
                $quantity = $request->measurement_item[$item_1] * $request->quantity_item[$item_1];
                if($inventory){
                    $inventoryQuantity = $inventory->quantity;
                    $inventory->quantity =  $inventoryQuantity + $quantity;
                    $inventory->save();
                }else{
                    $inventory = new Inventory(['item_id'=>$item->id ,'quantity' =>$quantity]);
                    $inventory->save();
                }
            }
        }
        Flash::success('Purchase Updated');
        return redirect()->route('purchases.index');
    }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Purchase  $purchase
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $purchase = Purchase::find($id);
          if (empty($purchase)) {
              return Response([
                  'status'=>0,
                  'msg'=>'Purchase Not Found'
              ]);
          }
          $purchase ->items()->detach();
          $purchase->delete();
          return Response([
              'status'=>1,
              'msg'=>'Purchase deleted'
          ]);
    }

    public function getItem(Request $request)
    {
        $itemName=$request->item;
        $Item = Item::where('name_en','=',$itemName)->get();
        $item_name=$Item[0]->name_ar;

        return $item_name;
    }


    public function get_supplier(Request $request){
        $supplier   = Supplier::where('id',$request->id)->first();
        return Response($supplier);
    }
}



