@extends('layouts.app')
@section('title')
Edit Purchase
@endsection
@section('content')
@if (count($errors) > 0)
<div class="alert alert-danger" role="alert">
    @foreach ($errors->all() as $error)
    {{ $error }}<br>
    @endforeach
</div>
@endif
<div class="col-md-12">
    <div class="main-card mb-3 card">
        <div class="card-body">
            <h5 class="card-title">{{ __('messages.edit_purchase') }}</h5>
            <form action="{{route('purchases.update', $purchase->id)}}" method="POST" enctype="multipart/form-data">
                @csrf
                {{ method_field('PATCH') }}
                <div class="row">
                    <div class="position-relative form-group col-md-6">
                        <label for="name" class="">{{ __('messages.invoice') }}</label>
                        <input required name="invoice" id="invoice" placeholder="{{ __('messages.invoice') }}" class="form-control" value="{{ $purchase->invoice_number}}">
                    </div>
                    <div class="position-relative form-group col-md-6">
                        <label for="image" class="">{{ __('messages.image') }}</label>
                        <input type="file" name="image" id="image" class="form-control" onchange="putImage()"accept="image/*" />
                        <img id="show_img" class="img-fit" src="{{asset('/images/'.$purchase->image)}}">
                    </div>
                </div>
                <div class="row">
                    <div class="position-relative form-group col-md-6">
                        <label for="invoice_date" class="">{{ __('messages.invoice_date') }}</label>
                        <input required name="invoice_date" id="invoice_date" placeholder="{{ __('messages.invoice_date') }}" class="form-control" type="date" value="{{ date('Y-m-d',strtotime($purchase->invoice_date ))}}">
                    </div>
                    <div class="position-relative form-group col-md-6">
                        <label for="invoice_due_date" class="">{{ __('messages.invoice_due_date') }}</label>
                        <input required name="invoice_due_date" id="invoice_due_date" placeholder="{{ __('messages.invoice_due_date') }}" class="form-control" type="date" value="{{ date('Y-m-d',strtotime($purchase->invoice_due_date))}}">
                    </div>
                </div>
                <div class="row">
                    <div class="position-relative form-group col-md-6">
                        <label for="supplier" class="">{{ __('messages.supplier') }}</label>
                        <select required name="supplier" id="supplier_select" class="form-control">
                            <option value="" selected disabled hidden>{{ __('messages.choose') }} {{ __('messages.supplier') }}</option>
                            <option value="other">{{ __('messages.add_new') }}</option>
                            @foreach($suppliers as $supplier)
                                <option value="{{$supplier->id }}" {{ $supplier->id == $purchase->supplier_id  ? 'selected' : '' }}>{{ $supplier->name }}</option>
                            @endforeach
                        </select>
                    </div>
                    {{--  <div id="otherName" class="position-relative form-group col-md-6">
                        <label class="">{{ __('messages.enter_supplier') }} </label>
                        <div class="d-flex">
                        <select name="supplier" value="{{ $purchase->suppliers['name'] }}"  required id="supplier" class="form-control">
                                <option value="" selected disabled hidden>{{ __('messages.choose') }} {{ __('messages.supplier') }}</option>
                                @foreach($suppliers as $supplier)
                                    <option value="{{ $supplier->id }}">{{ $supplier->name }}</option>
                                @endforeach
                                <option value="other">{{ __('messages.add_new') }}</option>
                            </select>

                        </div>
                    </div>  --}}
                </div>
                <div class="row">
                    <div class="position-relative form-group col-md-6">
                        <label for="payment_method" class="">{{ __('messages.payment_method') }}</label>
                        <input required name="payment_method" id="payment_method" placeholder="{{ __('messages.payment_method') }}" class="form-control" value="{{ $purchase->payment_method }}">
                    </div>
                    <div class="position-relative form-group col-md-6">
                        <label for="VAT_number" class="">{{ __('messages.vat_num') }}</label>
                        <input required name="VAT_number" id="VAT_number" placeholder="{{ __('messages.vat_num') }}" class="form-control" value="{{ $purchase->suppliers['vat_number'] }}">
                    </div>
                </div>
                <div class="row">
                    <div class="position-relative form-group col-md-6">
                        <label for="paid_amount" class="">{{ __('messages.paid_amount') }}</label>
                        <input type="number" required name="paid_amount" id="paid_amount" placeholder="{{ __('messages.paid_amount') }}" class="form-control" value="{{ $purchase->paid_amount }}" step="0.01" min="0">
                    </div>
                    <div class="position-relative form-group col-md-6">
                        <label for="total_amount" class="">{{ __('messages.total_amount') }}</label>
                        <input type="number" required name="total_amount" id="total_amount" placeholder="{{ __('messages.total_amount') }}" class="form-control" type="number" value="{{ $purchase->total_amount }}" step="0.01" min="0">
                    </div>
                </div>
                <hr>
                <div class="row">
                    <div class="card rounded-0 border-0 shadow col-md-12">
                        <div class="card-body p-10">

                            <!--  Bootstrap table-->
                            <div class="col-md-12">
                                <table id="table" class="table table-bordered table-responsive-lg" id="tblCustomers " >
                                    <thead>
                                    <tr>
                                        <th scope="col" >{{ __('messages.item_en') }}</th>
                                        <th scope="col">{{ __('messages.item_ar') }}</th>
                                        <th scope="col">{{ __('messages.quantity') }}</th>
                                        <th scope="col">{{ __('messages.measurement') }}</th>
                                        <th scope="col">{{ __('messages.unit') }}</th>
                                        <th scope="col">{{ __('messages.expiry_date') }}</th>
                                        <th scope="col" style="width: 70px"></th>
                                    </tr>
                                    </thead>
                                    <tbody>
                                    @foreach($purchase->items as $item)
                                        <tr>
                                            <td>{{ $item['name_en']}}</td>
                                            <td>{{ $item['name_ar']}}</td>
                                            <td>{{ $item['pivot']['quantity']}}</td>
                                            <td>{{ $item['pivot']['mesurment']}}</td>
                                            <td>{{$item['unit']}}</td>
                                            <td>{{$item['pivot']['expire_date']}}</td>
                                        </tr>
                                    @endforeach
                                    </tbody>
                                </table>
                            </div>

                            <!-- Add rows button-->
                            <a class="btn btn-primary" id="insertRow" href="#">{{ __('messages.add') }}</a>
                            <a class="btn btn-primary" id="insertRow_1" href="#">{{ __('messages.add_item') }}</a><span style="font-weight: bold;">  {{ __('messages.add_new_item') }} </span>


                        </div>
                    </div>

                </div>
                <a href="{{route('purchases.index')}}" class="mt-1 btn btn-danger ">{{ __('messages.cancel') }}</a>
                <button class="mt-1 btn bg-darkblue text-white">{{ __('messages.save') }}</button>
            </form>
        </div>
    </div>
</div>
@endsection
@section('script')

<script>
        $(document).ready(function() {
            $("#supplier_select").on("change", function() {
                alert($(this).val())
                if ($(this).val() === "other") {
                    $("#otherName").show();
                   // $('#sname');
                    //document.getElementsById('svat');
                    $('#VAT_number').val('')
                }
                else {
                    $.ajax({
                        method:'get',
                        data:{'id':$(this).val()},
                        url:base_url+'dashboard/get_supplier',
                        //url:'http://localhost:8080/kuppitek/public/index.php/dashboard/close_order',
                        success: function (data) {
                            console.log(data)
                            $('#VAT_number').val(data.vat_number)
                        }
                    });
                    $("#otherName").hide();
                }
            });
        });
    </script>
<script>

{{--    $(document).ready(function() {--}}
{{--        @foreach($inventories as $inventory)--}}
{{--        $('#delete_{{$inventory->id}}').on('click', function() {--}}
{{--            //var status = $(this).val();--}}
{{--            var id = $('#item_{{$inventory->id}}').val();--}}
{{--            var url = '{{ route("delete_item", ":id") }}';--}}
{{--            url = url.replace(':id', id);--}}
{{--            $.ajax({--}}
{{--                url: url,--}}
{{--                type: 'get',--}}
{{--                dataType: 'json',--}}
{{--                // data:{status :status},--}}
{{--                success: function(result) {--}}
{{--                    //  alert("The Ingredient Deleted");--}}
{{--                    window.location.reload();--}}

{{--                }--}}

{{--            });--}}
{{--        });--}}
{{--        @endforeach--}}
{{--    });--}}
</script>
<script>
    $(function () {

// Start counting from the third row
        var counter = 0;
        var jArray = <?php echo json_encode($items); ?>;
        $("#insertRow").on("click", function (event) {
            event.preventDefault();
            var newRow = $("<tr>");
            var cols = '';
            var option ;
            var option1 ;
            option='<option value=""   >{{ __('messages.select_item') }}</option>';
            option1='<option value=""   >{{ __('messages.select_item') }}</option>';
            for(var i=0; i<jArray.length; i++) {
                option +='<option value="' + jArray[i].name_en + '"   > ' + jArray[i].name_en + '</option>'
                option1 +='<option value="' + jArray[i].name_ar + '"   > ' + jArray[i].name_ar + '</option>'

                //  console.log(jArray[i].name_en);
                //$("#item_en").append('<option value="'+jArray[i].name_en+'"   > '+jArray[i].name_en+'</option>');
            }
        //    console.log(option);
            // Table columns
            // cols += '<td scrope="row">' + counter + '</td>';
            cols += '<td><select required  class="form-control rounded-0" name="item_en[]" id="item_en" > '+ option +' </select></td>';
            cols += '<td><select required class="form-control rounded-0" name="item_ar[]" id="item_ar" > '+ option1 +' </select></td>';
            cols += '<td><input required class="form-control rounded-0" type="number" name="quantity[]" id="quantity" style="width: 100%" min="0"></td>';
            cols += '<td><input required class="form-control rounded-0" type="number" name="measurement[]" id="measurement" style="width: 100%" min="0"></td>';
            cols += '<td><select name="unit[]" id="unit"><option value="g" selected="">g</option> <option value="kg">kg</option> <option value="l">l</option> <option value="ml">ml</option> <option value="piece">piece</option> </select></td>';
            cols += '<td><input required class="form-control rounded-0" type="date" name="expiry_date[]" id="expiry_date" style="width: 100%"></td>';
            cols += '<input type="hidden" name="detail_id[]" id="detail_id"   value =' + counter + '></td>';
            cols += '<td><button class="btn btn-danger rounded-0" id ="deleteRow"><i class="fa fa-trash"></i></button</td>';


            // Insert the columns inside a row
            newRow.append(cols);


            // // Insert the row inside a table
            $("#table").append(newRow);

            counter++;
        });
        // @endforech
// Remove row when delete btn is clicked
        $("#table").on("click", "#deleteRow", function (event) {
            $(this).closest("tr").remove();
            counter -= 1
        });
    });

    $(function () {

// Start counting from the third row
        var counter1 = 0;

        $("#insertRow_1").on("click", function (event) {
            event.preventDefault();
            var newRow_1 = $("<tr>");
            var cols_1 = '';

            // Table columns
            // cols += '<td scrope="row">' + counter + '</td>';
            cols_1 += '<td><input required class="form-control rounded-0" type="text" name="item_name_en[]" id="item_name_en" style="width: 100%"></td>';
            cols_1 += '<td><input required class="form-control rounded-0" type="text" name="item_name_ar[]" id="item_name_ar" style="width: 100%"></td>';
            cols_1 += '<td><input required class="form-control rounded-0" type="number" value="0" name="quantity_item[]" id="quantity" style="width: 100%"></td>';
            cols_1 += '<td><input required class="form-control rounded-0" type="number" value="0" name="measurement_item[]" id="measurement" style="width: 100%"></td>';
            cols_1 += '<td><select required name="item_unit[]" id="item_unit"><option value="g" selected="">g</option> <option value="kg">kg</option> <option value="l">l</option> <option value="ml">ml</option> <option value="piece">piece</option> </select></td>';
            cols_1 += '<td><input required class="form-control rounded-0" type="date" name="expiry_date_item[]" id="expiry_date_item" style="width: 100%"></td>';
            cols_1 += '<input type="hidden" name="detail_id_1[]" id="detail_id_1"   value =' + counter1 + '></td>';
            cols_1 += '<td><button class="btn btn-danger rounded-0" id ="deleteRow_1"><i class="fa fa-trash"></i></button</td>';


            // Insert the columns inside a row
            newRow_1.append(cols_1);

            // // Insert the row inside a table
            $("#table").append(newRow_1);

            counter1++;
        });

// Remove row when delete btn is clicked
        $("#table").on("click", "#deleteRow_1", function (event) {
            $(this).closest("tr").remove();
            counter1 -= 1
        });
    });


</script>

@endsection
