@extends('layouts.app')
@section('title')
    Purchases
@endsection
@section('content')
    <div class="col-md-12">
        <div class="main-card mb-3 card">
            <div class="card-body">
                @include('flash::message')
                <div class="d-flex justify-content-between align-items-center mb-3">
                    <h5 class="card-title p-2 mb-0 darkblue">{{ __('messages.purchases') }}</h5>
                    <a style="text-decoration: none;" href="{{ route('purchases.create') }}" class="bg-blue text-white p-2 border-round fw-bold">{{ __('messages.add_purchase') }}</a>
                </div>

                <table class="table table-striped w-100"data-replace="jtable" id="example" aria-label="JS Datatable" data-locale="en" data-search="true">
                    <thead>
                    <tr class="darkblue">
                        {{--  <th>#</th>  --}}
                        <th>{{ __('messages.invoice') }}</th>
                        <th>{{ __('messages.supplier') }}</th>
                        <th>{{ __('messages.invoice_due_date') }}</th>
                        <th>{{ __('messages.payment_method') }}</th>
                        <th>{{ __('messages.action') }}</th>
                    </tr>
                    </thead>
                    <tbody>

                        @foreach($purchases as $purchase)
                            <tr>
                                {{--  <td>{{ $purchase->id }}</td>  --}}
                                <td>{{ $purchase->invoice_number }}</td>
                                <td>{{ isset($purchase->suppliers['name'])?$purchase->suppliers['name']:"" }}</td>
                                <td>{{ isset($purchase->invoice_due_date)?
                                    \Carbon\Carbon::parse($purchase->invoice_due_date )->format('d-m-Y')
                                    :"" }}</td>
                                <td>{{ isset($purchase->payment_method)?$purchase->payment_method:"" }}</td>
                                <td>
                                    <div class="d-flex align-items-center">
                                        <a href="{{ route('purchases.edit', ['purchase'=>$purchase->id]) }}"><i class="px-2 fa-solid fa-pen-to-square green"></i></a>
                                        <a href="{{ route('purchases.show', ['purchase'=>$purchase->id]) }}"><i class="px-2 fa-solid fa-eye"></i></a>
                                        <a href="{{route('delete_purchase', ['id'=>$purchase->id])}}" class="del_purchase"><i class="px-2 fa-solid fa-trash-can red"></i></a>
                                    </div>

                                </td>
                            </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>
@endsection

@section('script')
<script>
    $(document).ready(function(){
        $('.del_purchase').each(function(){
            $(this).on('click',function(event){
                var elm = $(this);
                event.preventDefault();

                Swal.fire({
                    title: 'Are you sure?',
                    text: "You won't be able to revert this!",
                    type: 'warning',
                    showCancelButton: true,
                    confirmButtonColor: '#35fd80',
                    cancelButtonColor: '#d33',
                    confirmButtonText: 'Yes, delete it!'
                }).then((result) => {
                    if(result.value) {
                        $.ajax({
                            method:'get',
                            url:elm.attr('href'),
                            success: function (data) {
                                console.log(data)
                                if(data.status){
                                    Swal.fire({
                                        title: 'Deleted',
                                        text: data.msg,
                                        type: 'success',
                                        confirmButtonColor: '#35fd80',
                                        showConfirmButton:false,
                                        confirmButtonText: 'OK',
                                        timer:1000
                                    })
                                    location.reload();
                                }else{
                                    Swal.fire({
                                        title: data.msg,
                                        type: 'error',
                                        confirmButtonColor: '#35fd80',
                                        confirmButtonText: 'حسناً',
                                        })
                                }
                                //location.reload();
                            }
                        });
                    }
                })
            })
        })
    })
</script>
@endsection
